Package: ade4
Version: 1.7-23
Title: Analysis of Ecological Data: Exploratory and Euclidean Methods
        in Environmental Sciences
Authors@R: c(
   person("Stéphane", "Dray", email = "stephane.dray@univ-lyon1.fr", role = "aut", comment = c(ORCID = "0000-0003-0153-1105")),
   person("Anne-Béatrice", "Dufour", email = "anne-beatrice.dufour@univ-lyon1.fr", role = "aut", comment = c(ORCID = "0000-0002-9339-4293")),
   person("Jean", "Thioulouse", email = "jean.thioulouse@univ-lyon1.fr", role = "aut", comment = c(ORCID = "0000-0001-7664-0598")),
   person("Daniel", "Chessel", role = "ant"),
   person("Thibaut", "Jombart", role = "ctb"),
   person("Sandrine", "Pavoine",role = "ctb"),
   person("Jean R.", "Lobry", role = "ctb"),
   person("Sébastien", "Ollier", role = "ctb"),
   person("Daniel", "Borcard", role = "ctb"),
   person("Pierre", "Legendre", role = "ctb"),
   person("Stéphanie", "Bougeard", role = "ctb"),
   person("Aurélie", "Siberchicot", role = c("ctb", "cre"), email = "aurelie.siberchicot@univ-lyon1.fr", comment = c(ORCID = "0000-0002-7638-8318"))
	)
Depends: R (>= 3.5.0)
Imports: graphics, grDevices, methods, stats, utils, MASS, pixmap, sp,
        Rcpp
LinkingTo: Rcpp, RcppArmadillo
Suggests: ade4TkGUI, adegraphics, adephylo, adespatial, ape, CircStats,
        deldir, lattice, spdep, splancs, waveslim, progress, foreach,
        parallel, doParallel, iterators, knitr, rmarkdown
VignetteBuilder: knitr
Description: Tools for multivariate data analysis. Several methods are provided for the analysis (i.e., ordination) of one-table (e.g., principal component analysis, correspondence analysis), two-table (e.g., coinertia analysis, redundancy analysis), three-table (e.g., RLQ analysis) and K-table (e.g., STATIS, multiple coinertia analysis). The philosophy of the package is described in Dray and Dufour (2007) <doi:10.18637/jss.v022.i04>.
License: GPL (>= 2)
URL: https://adeverse.github.io/ade4/, http://pbil.univ-lyon1.fr/ADE-4/
BugReports: https://github.com/adeverse/ade4/issues
Encoding: UTF-8
NeedsCompilation: yes
Packaged: 2025-02-14 13:27:05 UTC; siberchicot
Author: Stéphane Dray [aut] (<https://orcid.org/0000-0003-0153-1105>),
  Anne-Béatrice Dufour [aut] (<https://orcid.org/0000-0002-9339-4293>),
  Jean Thioulouse [aut] (<https://orcid.org/0000-0001-7664-0598>),
  Daniel Chessel [ant],
  Thibaut Jombart [ctb],
  Sandrine Pavoine [ctb],
  Jean R. Lobry [ctb],
  Sébastien Ollier [ctb],
  Daniel Borcard [ctb],
  Pierre Legendre [ctb],
  Stéphanie Bougeard [ctb],
  Aurélie Siberchicot [ctb, cre]
    (<https://orcid.org/0000-0002-7638-8318>)
Maintainer: Aurélie Siberchicot <aurelie.siberchicot@univ-lyon1.fr>
Repository: CRAN
Date/Publication: 2025-02-14 14:20:02 UTC
Built: R 4.3.3; aarch64-apple-darwin20; 2025-02-15 06:55:56 UTC; unix
Archs: ade4.so.dSYM
