# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

RVintrarandtestCpp <- function(X, Y, fac, nrepet) {
    .Call(`C__ade4_RVintrarandtestCpp`, X, Y, fac, nrepet)
}

RVrandtestCpp <- function(X, Y, nrepet) {
    .Call(`C__ade4_RVrandtestCpp`, X, Y, nrepet)
}

procusterandtestCpp <- function(X, Y, nrepet) {
    .Call(`C__ade4_procusterandtestCpp`, X, Y, nrepet)
}

betweenvarCpp <- function(tab, pl, fac) {
    .Call(`C__ade4_betweenvarCpp`, tab, pl, fac)
}

testdiscriminCpp <- function(npermut, rang, pl, fac, tab) {
    .Call(`C__ade4_testdiscriminCpp`, npermut, rang, pl, fac, tab)
}

testertraceCpp <- function(npermut, pc1, pc2, X1, X2) {
    .Call(`C__ade4_testertraceCpp`, npermut, pc1, pc2, X1, X2)
}

testertracenuCpp <- function(npermut, pc1, pc2, pl, tab1, tab2, tabinit1, tabinit2, typ1, typ2) {
    .Call(`C__ade4_testertracenuCpp`, npermut, pc1, pc2, pl, tab1, tab2, tabinit1, tabinit2, typ1, typ2)
}

testertracenubisCpp <- function(npermut, pc1, pc2, pl, tab1, tab2, tabinit1, tabinit2, typ1, typ2, ntab) {
    .Call(`C__ade4_testertracenubisCpp`, npermut, pc1, pc2, pl, tab1, tab2, tabinit1, tabinit2, typ1, typ2, ntab)
}

inerbetweenCpp <- function(pl, pc, moda, indica, tab) {
    .Call(`C__ade4_inerbetweenCpp`, pl, pc, moda, indica, tab)
}

testinterCpp <- function(npermut, pl, pc, fac, tab) {
    .Call(`C__ade4_testinterCpp`, npermut, pl, pc, fac, tab)
}

testmantelCpp <- function(npermut, m1, m2) {
    .Call(`C__ade4_testmantelCpp`, npermut, m1, m2)
}

